Installing and Building
=======================

installing from pypi
--------------------

The easiest way to install OPICS is using pip pypi::

    pip install opics

Building from source
--------------------

First, obtain the OPICS source code::

    git clone https://github.com/siepic/opics

Install the OPICS package using ``pip``::

    pip install ./opics

Once the package is installed, it is ready to use and can be imported using::
    
    import opics as op

